@@ -1,6 +1,6 @@
-//$Id: app-res.cc,v 1.12 2001/12/17 22:56:04 cactus Exp $ -*- c++ -*-
+//$Id: app-res.cc,v 1.15 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -17,6 +17,7 @@
  */
 
 #include "app-res.h"
+#include "app-win.h"
 
 #include "config.h"
 #include <libgnome/libgnome.h>
@@ -62,6 +63,9 @@ void Resources::Application::reset ()
     version = "";
     vendor = "";
 
+    if (gui)
+	gui->hide ();
+
     changed ();
 }
 
