@@ -1,6 +1,6 @@
-//$Id: dialog-win.cc,v 1.23 2001/12/09 18:55:55 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.25 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -193,7 +193,8 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
     
     type_menu->show_all ();
     type_combo.set_menu (*manage (type_menu));
-    proptable->add (_("T_ype:"), type_combo);
+    proptable->add (_("T_ype:"), type_combo,
+		    _("An icon will be included in the dialog, based on its type"));
     
     /* Help ID */
     control = new GUI::PropertyEditors::ResourceCombo (Resources::RESOURCE_STRING, res->help_id);
