@@ -1,6 +1,6 @@
-//$Id: button-canvas.cc,v 1.13 2001/12/23 00:11:22 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.cc,v 1.15 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -24,9 +24,9 @@
 
 using namespace Guikachu::GUI::FormEditor;
 
-ButtonCanvasItem::ButtonCanvasItem (Widgets::Button  *widget_,
-				    FormEditor::Form *form):
-    CanvasItem (widget_, form),
+ButtonCanvasItem::ButtonCanvasItem (Widgets::Button    *widget_,
+				    Gnome::CanvasGroup *parent_group):
+    WidgetCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
 {
@@ -222,7 +222,7 @@ void ButtonCanvasItem::update ()
     if (group)
 	delete group;
 
-    group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
+    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
     
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
