@@ -1,6 +1,6 @@
-//$Id: button.cc,v 1.27 2001/11/15 20:21:59 cactus Exp $ -*- c++ -*-
+//$Id: button.cc,v 1.29 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -51,9 +51,9 @@ Gtk::Widget *Button::create_editor ()
     return editor->get_editor ();
 }
 
-CanvasItem* Button::create_canvas_item (GUI::FormEditor::Form *form)
+WidgetCanvasItem* Button::create_canvas_item (Gnome::CanvasGroup *parent_group)
 {
-    return new ButtonCanvasItem (this, form);
+    return new ButtonCanvasItem (this, parent_group);
 }
 
 
