@@ -1,6 +1,6 @@
-//$Id: canvasitem.cc,v 1.22 2001/12/19 22:04:00 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.cc,v 1.25 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -18,76 +18,50 @@
 
 #include "canvasitem.h"
 
-#include "config.h"
-#include <libgnome/libgnome.h>
-
-#include <gnome--/canvas-rect.h>
-#include <gnome--/app-helper.h>
-#include <libgnomeui/gnome-stock.h>
-
-#include <list>
+#include <algorithm>
 #include <math.h>
+#include <sigc++/retbind.h>
 
 #include "form-editor.h"
 
 using namespace Guikachu::GUI::FormEditor;
 
-CanvasItem::CanvasItem (Widget           *widget_,
-			FormEditor::Form *form_):
-    item (0),
-    widget (widget_),
-    bounding_box (0),
-    form (form_),
-    selected (false)
+CanvasItem::CanvasItem (FormElement        *form_element_,
+			Gnome::CanvasGroup *parent_group_):
+    form_element (form_element_),
+    parent_group (parent_group_),
+    item (0)
 {
     drag_context.dragging = false;
     drag_context.drag_occured = false;
-    
-    // Popup menu
-    std::list <Gnome::UI::Info> popup_menu_list;
-    popup_menu_list.push_back (
-	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_PROP),
-			 _("_Edit"), menu_edit.slot ()));
-    popup_menu_list.push_back (
-	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_TRASH),
-			 _("_Remove"), menu_remove.slot ()));
-    
-    Gnome::UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
-    
-    widget->changed.connect  (SigC::slot (this, &CanvasItem::update));
-    widget->selected.connect (SigC::slot (this, &CanvasItem::widget_selected_cb));
 }
 
 CanvasItem::~CanvasItem ()
 {
     if (item)
 	delete item;
-
-    if (bounding_box)
-	delete bounding_box;
 }
 
 void CanvasItem::set_canvas_item (Gnome::CanvasGroup *item_)
 {
     item = item_;
-    bounding_box = 0;
     
-    item->event.connect (SigC::slot (this, &CanvasItem::canvas_event_cb));
-    widget_selected_cb (selected);
+    item->event.connect (SigC::retbind (
+	    SigC::slot (this, &CanvasItem::canvas_event_cb), 1));
 }
 
-int CanvasItem::canvas_event_cb (GdkEvent *e)
+void CanvasItem::canvas_event_cb (GdkEvent *e)
 {
     // Single click
-    if ((e->type == GDK_BUTTON_PRESS) &&
-	(e->button.button == 1))
-	clicked ();
+    if (e->type == GDK_BUTTON_PRESS &&
+	e->button.button == 1)
+	clicked.emit ();
+
+    // Single click -- release
+    if (e->type == GDK_BUTTON_RELEASE &&
+	e->button.button == 1)
+	released.emit ();
 
-    // Context menu
-    if ((e->type == GDK_BUTTON_PRESS) &&
-	(e->button.button == 3))
-	popup_menu.popup (e->button.button, e->button.time);
-    
     // Begin drag
     if (e->type == GDK_BUTTON_PRESS &&
 	e->button.button == 1 &&
@@ -101,11 +75,9 @@ int CanvasItem::canvas_event_cb (GdkEvent *e)
 
     // Ending drag
     if (e->type == GDK_BUTTON_RELEASE &&
-	(e->button.button == 1) &&
+	e->button.button == 1 &&
 	drag_context.dragging)
 	drag_end_impl (e);
-    
-    return TRUE;
 }
 
 void CanvasItem::drag_begin_impl (GdkEvent *e)
@@ -116,8 +88,8 @@ void CanvasItem::drag_begin_impl (GdkEvent *e)
     drag_context.last_x = drag_context.start_x = e->button.x;
     drag_context.last_y = drag_context.start_y = e->button.y;
     
-    drag_context.offset_x = drag_context.last_x - widget->x;
-    drag_context.offset_y = drag_context.last_y - widget->y;
+    drag_context.offset_x = drag_context.last_x - form_element->get_x ();
+    drag_context.offset_y = drag_context.last_y - form_element->get_y ();
 
     drag_context.delta_remainder_x = 0;
     drag_context.delta_remainder_y = 0;
@@ -185,50 +157,3 @@ void CanvasItem::move (int dx, int dy)
 {
     item->move (dx, dy);
 }
-
-void CanvasItem::widget_selected_cb (bool selected_)
-{
-    selected = selected_;
-    
-    if (!selected)
-    {
-	if (bounding_box)
-	{
-	    delete bounding_box;
-	    bounding_box = 0;
-	}
-	return;
-    }
-
-    delete bounding_box;
-    bounding_box = create_bounding_box ();
-    item->raise_to_top ();
-}
-
-Gnome::CanvasItem * CanvasItem::create_bounding_box ()
-{
-    int x1, y1, x2, y2;
-    
-    get_bounds (x1, y1, x2, y2);
-
-    using namespace Gnome::CanvasHelpers;
-    Gnome::CanvasRect *bounding_box = new Gnome::CanvasRect (*item, x1, y1, x2, y2);
-    *bounding_box
-	<< width_units (2)
-	<< outline_color (get_selection_color ());
-
-    return bounding_box;
-}
-
-void CanvasItem::get_bounds (int &x1, int &y1,
-			     int &x2, int &y2)
-{
-    double x1_, y1_, x2_, y2_;
-    
-    item->get_bounds (x1_, y1_, x2_, y2_);
-
-    x1 = (int)x1_ - 2;
-    y1 = (int)y1_ - 2;
-    x2 = (int)x2_ + 2;
-    y2 = (int)y2_ + 2;
-}
