@@ -1,6 +1,6 @@
-//$Id: canvasitem.h,v 1.12 2001/12/21 17:20:18 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.h,v 1.15 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -32,9 +32,8 @@ namespace Guikachu
 
 #include <sigc++/basic_signal.h>
 #include <gnome--/canvas-group.h>
-#include <gtk--/menu.h>
 
-#include "widget.h"
+#include "form-element.h"
 
 namespace Guikachu
 {
@@ -44,11 +43,7 @@ namespace Guikachu
 	{
 	    class CanvasItem: public SigC::Object
 	    {
-		Gnome::CanvasGroup *item;
-		Widget             *widget;
-		Gnome::CanvasItem  *bounding_box;
-
-		Gtk::Menu           popup_menu;
+		FormElement *form_element;
 		
 		struct
 		{
@@ -62,44 +57,34 @@ namespace Guikachu
 		} drag_context;
 		
 	    protected:
-		FormEditor::Form  *form;
-		bool selected;
+		Gnome::CanvasGroup *parent_group;
+		Gnome::CanvasGroup *item;
+		virtual void set_canvas_item (Gnome::CanvasGroup *item);
 		
 	    protected:
-		CanvasItem (Widget           *widget,
-			    FormEditor::Form *form);
-		
-		void set_canvas_item (Gnome::CanvasGroup *item);
+		CanvasItem (FormElement        *form_element,
+			    Gnome::CanvasGroup *parent_group);
 		
 	    public:
 		virtual ~CanvasItem ();
 
 		virtual void update () = 0;
-		
+		virtual void move (int dx, int dy);
+		    
 		SigC::Signal0<void> clicked;
+		SigC::Signal0<void> released;
 
-		SigC::Signal0<void> menu_edit;
-		SigC::Signal0<void> menu_remove;
-		
 		SigC::Signal0<void>           drag_begin;
 		SigC::Signal2<void, int, int> drag_motion; // arguments are dx and dy
 		SigC::Signal2<void, int, int> drag_end;    // arguments are dx and dy
 		SigC::Signal0<void>           drag_cancel;
 
-		void move (int dx, int dy);
-		
 	    private:
-		void widget_selected_cb (bool      selected);
-		int  canvas_event_cb    (GdkEvent *event);
+		void canvas_event_cb  (GdkEvent *event);
 
 		void drag_begin_impl  (GdkEvent *event);
 		void drag_motion_impl (GdkEvent *event);
 		void drag_end_impl    (GdkEvent *event);
-
-	    protected:
-		virtual Gnome::CanvasItem * create_bounding_box ();
-		virtual void get_bounds (int &x1, int &y1,
-					 int &x2, int &y2);
 	    };
 	}
     }
