@@ -1,6 +1,6 @@
-//$Id: checkbox.cc,v 1.16 2001/12/19 22:04:00 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.cc,v 1.18 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -123,9 +123,9 @@ Gtk::Widget *Checkbox::create_editor ()
     return editor->get_editor ();
 }
 
-CanvasItem* Checkbox::create_canvas_item (GUI::FormEditor::Form *form)
+WidgetCanvasItem* Checkbox::create_canvas_item (Gnome::CanvasGroup *parent_group)
 {
-    return new CheckboxCanvasItem (this, form);
+    return new CheckboxCanvasItem (this, parent_group);
 }
 
 bool Checkbox::load (StorageNode &node)
