@@ -1,6 +1,6 @@
-//$Id: gadget-canvas.h,v 1.1 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
+//$Id: gadget-canvas.h,v 1.3 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -20,8 +20,7 @@
 #define GUIKACHU_FORM_EDITOR_GADGET_CANVAS_H
 
 #include "gadget.h"
-
-#include <gnome--/canvas-group.h>
+#include "widget-canvas.h"
 
 namespace Guikachu
 {
@@ -29,13 +28,13 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class GadgetCanvasItem: public CanvasItem
+	    class GadgetCanvasItem: public WidgetCanvasItem
 	    {
 		Widgets::Gadget    *widget;
 		Gnome::CanvasGroup *group;
 	    public:
-		GadgetCanvasItem (Widgets::Gadget *res,
-				  FormEditor::Form  *form);
+		GadgetCanvasItem (Widgets::Gadget    *res,
+				  Gnome::CanvasGroup *parent_group);
 	    protected:
 		virtual void update ();
 	    };
