@@ -1,6 +1,6 @@
-//$Id: label-canvas.cc,v 1.7 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
+//$Id: label-canvas.cc,v 1.9 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -24,9 +24,9 @@
 
 using namespace Guikachu::GUI::FormEditor;
 
-LabelCanvasItem::LabelCanvasItem (Widgets::Label   *widget_,
-				  FormEditor::Form *form):
-    CanvasItem (widget_, form),
+LabelCanvasItem::LabelCanvasItem (Widgets::Label     *widget_,
+				  Gnome::CanvasGroup *parent_group):
+    WidgetCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
 {
@@ -38,7 +38,7 @@ void LabelCanvasItem::update ()
     if (group)
 	delete group;
     
-    group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
+    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
 
     draw_text (*group,
 	       widget->text, widget->font,
