@@ -1,6 +1,6 @@
-//$Id: list-canvas.cc,v 1.16 2001/12/16 15:44:30 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.18 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -25,9 +25,9 @@
 
 using namespace Guikachu::GUI::FormEditor;
 
-ListCanvasItem::ListCanvasItem (Widgets::List    *widget_,
-				FormEditor::Form *form):
-    CanvasItem (widget_, form),
+ListCanvasItem::ListCanvasItem (Widgets::List      *widget_,
+				Gnome::CanvasGroup *parent_group):
+    WidgetCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
 {
@@ -39,7 +39,7 @@ void ListCanvasItem::update ()
     if (group)
 	delete group;
     
-    group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
+    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
 
     int font_num = widget->font;    
     int height = get_font_height (font_num) * widget->visible_items;
