@@ -1,6 +1,6 @@
-//$Id: list-canvas.h,v 1.3 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.h,v 1.5 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -20,11 +20,7 @@
 #define GUIKACHU_FORM_EDITOR_LIST_CANVAS_H
 
 #include "list.h"
-
-#include <gnome--/canvas-group.h>
-
-using Guikachu::Widgets::List;
-using namespace Guikachu::GUI::FormEditor;
+#include "widget-canvas.h"
 
 namespace Guikachu
 {
@@ -32,13 +28,13 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class ListCanvasItem: public CanvasItem
+	    class ListCanvasItem: public WidgetCanvasItem
 	    {
 		Widgets::List      *widget;
 		Gnome::CanvasGroup *group;
 	    public:
-		ListCanvasItem (Widgets::List   *widget,
-				FormEditor::Form *form);
+		ListCanvasItem (Widgets::List      *widget,
+				Gnome::CanvasGroup *parent_group);
 	    protected:
 		virtual void update ();
 	    };
