@@ -1,6 +1,6 @@
-//$Id: popup-trigger.cc,v 1.14 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.16 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -50,9 +50,9 @@ Gtk::Widget *PopupTrigger::create_editor ()
     return editor->get_editor ();
 }
 
-CanvasItem* PopupTrigger::create_canvas_item (GUI::FormEditor::Form *form)
+WidgetCanvasItem* PopupTrigger::create_canvas_item (Gnome::CanvasGroup *parent_group)
 {
-    return new PopupTriggerCanvasItem (this, form);
+    return new PopupTriggerCanvasItem (this, parent_group);
 }
 
 bool PopupTrigger::load (StorageNode &node)
