@@ -1,6 +1,6 @@
-//$Id: popup-trigger.h,v 1.11 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.h,v 1.13 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -51,8 +51,8 @@ namespace Guikachu
 	    
 	    virtual Type get_type () const { return WIDGET_POPUP_TRIGGER; };
 	    
-	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
-	    virtual Gtk::Widget                 *create_editor ();
+	    virtual Gtk::Widget                       *create_editor ();
+	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 	    
 	    Properties::WidgetRef list_id;
 	    Property<bool>        usable;
