@@ -1,6 +1,6 @@
-//$Id: scrollbar-canvas.h,v 1.2 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-canvas.h,v 1.4 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -20,8 +20,7 @@
 #define GUIKACHU_FORM_EDITOR_SCROLLBAR_CANVAS_H
 
 #include "scrollbar.h"
-
-#include <gnome--/canvas-group.h>
+#include "widget-canvas.h"
 
 namespace Guikachu
 {
@@ -29,13 +28,13 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class ScrollBarCanvasItem: public CanvasItem
+	    class ScrollBarCanvasItem: public WidgetCanvasItem
 	    {
 		Widgets::ScrollBar *widget;
 		Gnome::CanvasGroup *group;
 	    public:
 		ScrollBarCanvasItem (Widgets::ScrollBar *widget,
-				     FormEditor::Form   *form);
+				     Gnome::CanvasGroup *parent_group);
 	    protected:
 		virtual void update ();
 	    };
