@@ -1,6 +1,6 @@
-//$Id: scrollbar.cc,v 1.13 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.cc,v 1.15 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -78,9 +78,9 @@ Gtk::Widget* ScrollBar::create_editor ()
     return editor->get_editor ();
 }
 
-CanvasItem* ScrollBar::create_canvas_item (GUI::FormEditor::Form *form)
+WidgetCanvasItem* ScrollBar::create_canvas_item (Gnome::CanvasGroup *parent_group)
 {
-    return new ScrollBarCanvasItem (this, form);
+    return new ScrollBarCanvasItem (this, parent_group);
 }
 
 bool ScrollBar::load (StorageNode &node)
