@@ -1,6 +1,6 @@
-//$Id: scrollbar.h,v 1.9 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.h,v 1.11 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -49,8 +49,8 @@ namespace Guikachu
 	    
 	    virtual Type get_type () const { return WIDGET_SCROLLBAR; };
 	    
-	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
-	    virtual Gtk::Widget                 *create_editor ();
+	    virtual Gtk::Widget                       *create_editor ();
+	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    Property<bool> usable;
 	    Property<int>  min_value, max_value, value, page_size;
