@@ -1,6 +1,6 @@
-//$Id: selector-trigger-canvas.cc,v 1.16 2001/12/16 15:44:30 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-canvas.cc,v 1.18 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -25,8 +25,8 @@
 using namespace Guikachu::GUI::FormEditor;
 
 SelectorTriggerCanvasItem::SelectorTriggerCanvasItem (Widgets::SelectorTrigger *widget_,
-						      FormEditor::Form         *form):
-    CanvasItem (widget_, form),
+						      Gnome::CanvasGroup       *parent_group):
+    WidgetCanvasItem (widget_, parent_group),
     widget (widget_),
     group (0)
 {
@@ -38,7 +38,7 @@ void SelectorTriggerCanvasItem::update ()
     if (group)
 	delete group;
 
-    group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
+    group = new Gnome::CanvasGroup (*parent_group, 0, 0);
     
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
@@ -89,8 +89,8 @@ void SelectorTriggerCanvasItem::get_bounds (int &x1, int &y1,
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
     
-    x1 = widget->x;
+    x1 = widget->x - 1;
     x2 = x1 + width + 1;
-    y1 = widget->y;
+    y1 = widget->y - 1;
     y2 = y1 + height + 1;
 }
