@@ -1,6 +1,6 @@
-//$Id: selector-trigger-canvas.h,v 1.3 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-canvas.h,v 1.5 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -20,8 +20,7 @@
 #define GUIKACHU_FORM_EDITOR_SELECTOR_TRIGGER_CANVAS_H
 
 #include "selector-trigger.h"
-
-#include <gnome--/canvas-group.h>
+#include "widget-canvas.h"
 
 namespace Guikachu
 {
@@ -29,13 +28,13 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class SelectorTriggerCanvasItem: public CanvasItem
+	    class SelectorTriggerCanvasItem: public WidgetCanvasItem
 	    {
 		Widgets::SelectorTrigger *widget;
 		Gnome::CanvasGroup       *group;
 	    public:
 		SelectorTriggerCanvasItem (Widgets::SelectorTrigger *widget,
-					   FormEditor::Form         *form);
+					   Gnome::CanvasGroup       *parent_group);
 	    protected:
 		virtual void update ();
 		virtual void get_bounds (int &x1, int &y1,
