@@ -1,6 +1,6 @@
-//$Id: text-field-canvas.h,v 1.3 2001/10/18 20:41:43 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.h,v 1.5 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -20,7 +20,7 @@
 #define GUIKACHU_FORM_EDITOR_TEXT_FIELD_CANVAS_H
 
 #include "form-editor/text-field.h"
-#include "form-editor/canvasitem.h"
+#include "form-editor/widget-canvas.h"
 
 namespace Guikachu
 {
@@ -28,13 +28,13 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class TextFieldCanvasItem: public CanvasItem
+	    class TextFieldCanvasItem: public WidgetCanvasItem
 	    {
 		Widgets::TextField *widget;
 		Gnome::CanvasGroup *group;
 	    public:
-		TextFieldCanvasItem (Widgets::TextField    *widget,
-				     GUI::FormEditor::Form *form);
+		TextFieldCanvasItem (Widgets::TextField *widget,
+				     Gnome::CanvasGroup *parent_group);
 	    protected:
 		virtual void update ();
 		virtual void get_bounds (int &x1, int &y1,
