@@ -1,4 +1,4 @@
-//$Id: text-field-prop.cc,v 1.6 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: text-field-prop.cc,v 1.7 2002/01/05 23:35:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,6 +29,7 @@
 #include "widgets/num-entry.h"
 #include "widgets/togglebutton.h"
 #include "widgets/propertytable.h"
+#include "widgets/font-combo.h"
 
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
@@ -50,7 +51,7 @@ TextFieldProperties::TextFieldProperties (TextField *res)
 		    _("Non-usable widgets are not rendered by default"));
 
     /* Font */
-    control = new GUI::PropertyEditors::NumEntry (0, 2, res->font);
+    control = new GUI::PropertyEditors::FontCombo (res->font);
     proptable->add (_("_Font:"), *manage (control));
     
     /* Editable */
