@@ -1,6 +1,6 @@
-//$Id: widget.h,v 1.28 2001/12/19 22:04:00 cactus Exp $ -*- c++ -*-
+//$Id: widget.h,v 1.30 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -47,24 +47,25 @@ namespace Guikachu
 #include <string>
 #include <map>
 #include <iostream>
-#include <gnome-xml/tree.h>
 #include <sigc++/basic_signal.h>
 
+#include "storage-node.h"
 #include "form-res.h"
-#include "form.h"
-#include "canvasitem.h"
+#include "form-editor/widget-canvas.h"
+#include "form-editor/form-element.h"
 
 #include "property.h"
 
 namespace Guikachu
 {
-    class Widget: public SigC::Object
+    class Widget: public FormElement,
+		  public SigC::Object
     {
     protected:
-	typedef std::map<GUI::FormEditor::Form*,
-	    GUI::FormEditor::CanvasItem*> canvas_item_map_t;
+	typedef std::map<Gnome::CanvasGroup *,
+	    GUI::FormEditor::WidgetCanvasItem*> canvas_item_map_t;
 	
-	Resources::Form            *owner;
+	Resources::Form           *owner;
 	mutable Gtk::Widget       *editor;
 	mutable canvas_item_map_t  canvas_items;
 	
@@ -83,13 +84,17 @@ namespace Guikachu
 	ID            id;
 	Property<int> x;
 	Property<int> y;
+
+	// FormElement implementations
+	int get_x () const { return x; };
+	int get_y () const { return y; };
 	
 	// Preview-related methods
-	GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
-	Gtk::Widget                 *get_editor      ();
+	GUI::FormEditor::WidgetCanvasItem *get_canvas_item (Gnome::CanvasGroup *parent_group);
+	Gtk::Widget                       *get_editor      ();
 	
-	virtual Gtk::Widget                 *create_editor      () = 0;
-	virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form) = 0;
+	virtual Gtk::Widget                       *create_editor      () = 0;
+	virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group) = 0;
 	
 	Resources::Form *get_form () const { return owner; };
 	
