@@ -1,6 +1,6 @@
-//$Id: form-win.h,v 1.25 2001/12/21 17:17:44 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.29 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -29,6 +29,7 @@ namespace Guikachu
 
 #include "form-res.h"
 #include "form-editor/form.h"
+#include "form-editor/form-canvas.h"
 #include "form-editor/widget.h"
 
 #include <gtk--/window.h>
@@ -43,18 +44,27 @@ namespace Guikachu
 {
     namespace GUI
     {
+	namespace FormWindow_Helpers
+	{
+	    class CanvasSelectionWrapper;
+	}
+	
 	class FormWindow: public SigC::Object
 	{
-	    Resources::Form   *res;
+	    Resources::Form *res;
 	    
-	    GladeXML          *gui;
-	    Gtk::Window       *window;
-	    Gtk::Window       *property_window;
+	    GladeXML        *gui;
+	    Gtk::Window     *window;
+	    Gtk::Window     *property_window;
 	    
-	    Gnome::Canvas     *canvas;
-	    Gtk::SpinButton   *zoom_entry;
-	    Gtk::TreeItem     *top_treeitem;
-	    FormEditor::Form  *form_canvasitem;
+	    Gnome::Canvas   *canvas;
+	    Gtk::SpinButton *zoom_entry;
+	    Gtk::TreeItem   *top_treeitem;
+
+	    Widgets::Form              *form_widget;
+	    FormEditor::FormCanvasItem *form_canvas_item;
+
+	    FormWindow_Helpers::CanvasSelectionWrapper *selection_canvas;
 
 	    Widget            *edited_widget;
 	    std::set<Widget*>  selected_widgets;
@@ -62,12 +72,12 @@ namespace Guikachu
 	    
 	    Gnome::CanvasItem *canvas_overlay;
 	    Widgets::Type      palette_selection;
+
 	public:
 	    FormWindow (Resources::Form *res);
 	    ~FormWindow ();
 	    void show ();
 	    
-	    Gnome::Canvas *get_canvas () const { return canvas; };
 	private:
 	    void show_property_editor (Widget *widget);
 	    void show_form_property_editor ();
@@ -79,7 +89,11 @@ namespace Guikachu
 	    
 	    void update ();
 	    void edited_widget_changed ();
+
+	    void force_canvas_update ();
+	    void recenter_canvas ();
 	    void colors_changed_cb ();
+	    void target_changed_cb ();
 
 	    void palette_cb (Widgets::Type type);
 	    int canvas_overlay_cb (GdkEvent *event);
@@ -91,10 +105,21 @@ namespace Guikachu
 	    void widget_removed_cb (Widget *widget);
 
 	    void widget_menu_remove_cb (Widget *widget);
-	    
-	    void form_clicked_cb ();
-	    void widget_clicked_cb (Widget *widget);
 
+	    void form_select_cb   ();
+	    void form_clicked_cb  ();
+	    void form_released_cb ();
+
+	    void widget_select_cb   (Widget *widget);
+	    void widget_clicked_cb  (Widget *widget);
+	    void widget_released_cb (Widget *widget);
+	    
+	    void selection_box_cb (int x1, int y1,
+				   int x2, int y2);
+	    
+	    void form_drag_motion_cb   (int dx, int dy);
+	    void form_drag_end_cb      (int dx, int dy);
+	    
 	    void widget_drag_motion_cb (int dx, int dy);
 	    void widget_drag_end_cb    (int dx, int dy);
 	};
