@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.17 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.18 2002/01/09 17:26:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,20 +36,20 @@ static string time_ago_string (time_t ago)
     int days = hours / 24;
 
     if (days > 1)
-	buf = g_strdup_printf ("If you don't save, your work from "
-			       "the last %d days will be lost.",
+	buf = g_strdup_printf (_("If you don't save, your work from "
+				 "the last %d days will be lost."),
 			       days);
     else if (hours > 1)
-	buf = g_strdup_printf ("If you don't save, your work from "
-			       "the last %d hours will be lost.",
+	buf = g_strdup_printf (_("If you don't save, your work from "
+				 "the last %d hours will be lost."),
 			       hours);
     else if (minutes > 1)
-	buf = g_strdup_printf ("If you don't save, your work from "
-			       "the last %d minutes will be lost.",
+	buf = g_strdup_printf (_("If you don't save, your work from "
+				 "the last %d minutes will be lost."),
 			       minutes);
     else
-	buf = g_strdup_printf ("If you don't save, your work from "
-			       "the last minute will be lost.");
+	buf = g_strdup_printf (_("If you don't save, your work from "
+				 "the last minute will be lost."));
 
     ret_val = buf;
     g_free (buf);
