@@ -1,6 +1,6 @@
-//$Id: mainwin.cc,v 1.21 2001/12/20 23:42:48 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.23 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -269,7 +269,7 @@ void GUI::show_about ()
     Gnome::About *about = new Gnome::About ("Guikachu", VERSION,
 					    "(C) 2001 Gerg rdi",
 					    authors,
-					    "PalmOS resource file editor");
+					    _("PalmOS resource file editor"));
     about->run ();  
 }
 
